@@ -35,8 +35,13 @@ anova_stats(fit)
 anova_stats(car::Anova(fit, type = 3))
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-eta_sq(fit, partial = TRUE, ci.lvl = .8)
+if (requireNamespace("apaTables", quietly = TRUE)) {
+  eta_sq(fit, partial = TRUE, ci.lvl = .8)
+}
 
 # uses bootstrapping - here, for speed, just 100 samples
-omega_sq(fit, partial = TRUE, ci.lvl = .9, n = 100)
+if (requireNamespace("MBESS", quietly = TRUE)) {
+  omega_sq(fit, partial = TRUE, ci.lvl = .9, n = 100)
+}
+
 
